# Copyright (c) 2000-2011, JPackage Project
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions
# are met:
#
# 1. Redistributions of source code must retain the above copyright
#    notice, this list of conditions and the following disclaimer.
# 2. Redistributions in binary form must reproduce the above copyright
#    notice, this list of conditions and the following disclaimer in the
#    documentation and/or other materials provided with the
#    distribution.
# 3. Neither the name of the JPackage Project nor the names of its
#    contributors may be used to endorse or promote products derived
#    from this software without specific prior written permission.
#
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
# "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
# LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
# A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
# OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
# SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
# LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
# DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
# THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
# (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
# OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

%bcond_without repolib

%global namedversion %{version}

%define section free

Name:           google-collections
Version:        1.0
Release:        3.3%{?dist}
Epoch:          0
Summary:        Google Collections Library
License:        ASL 2.0
Group:          Development/Libraries/Java
URL:            http://code.google.com/p/google-collections/
Source0:        http://google-collections.googlecode.com/files/google-collect-1.0.zip
Source1:        http://google-maven-repository.googlecode.com/svn/repository/com/google/collections/google-collections/1.0/google-collections-1.0.pom
Source2:        %{name}-build.xml
# get it from  http://google-collections.googlecode.com/svn/trunk/build.xml
Source3:        %{name}-build.properties
# get it from  http://google-collections.googlecode.com/svn/trunk/build.properties
Source4:        %{name}-COPYING
# get it from  http://google-collections.googlecode.com/svn/trunk/COPYING
Source5:        %{name}-testfw.tar.gz
# svn export http://google-collections.googlecode.com/svn/trunk/testfw/ google-collections-testfw
Source6:        %{name}-test.tar.gz
# svn export http://google-collections.googlecode.com/svn/trunk/test/ google-collections-test

Patch0:         google-collections-javadoc-crosslink.patch
Patch1:         google-collections-MapsTest.patch
Patch2:         google-collections-ImmutableSortedMapTest.patch
Patch3:         google-collections-junit4.patch
Provides:       google-collect = %{epoch}:%{version}-%{release}
Requires:       jpackage-utils
BuildRequires:  ant >= 0:1.7.1
BuildRequires:  java-devel >= 0:1.6.0
BuildRequires:  java-javadoc
BuildRequires:  jpackage-utils
BuildRequires:  cglib
BuildRequires:  easymock2
BuildRequires:  easymock-classextension2
BuildRequires:  jsr-305
BuildRequires:  jsr-305-javadoc
BuildRequires:  junit4
BuildRequires:  objectweb-asm
BuildRequires:  tl4j
%if %with repolib
BuildRequires:  maven2-plugin-deploy
%endif
Buildarch:      noarch
BuildRoot:      %{_tmppath}/%{name}-%{version}-%{release}-root

%description
The Google Collections Library 1.0 is a suite of new 
collections and collection-related goodness for Java 5.0, 
brought to you by Google.

This library is a natural extension of the Java Collections
Framework you already know and love.

The major new types are:

* BiMap. A Map that guarantees unique values, and supports 
  an inverse view.
* Multiset. A Collection that may contain duplicate values 
  like a List, yet has order-independent equality like a Set.
  Often used to represent a histogram.
* Multimap. Similar to Map, but may contain duplicate keys.
  Has subtypes SetMultimap and ListMultimap providing more 
  specific behavior. 

There are also more than a dozen collection implementations,
mostly of the interfaces above, but not all. ReferenceMap, 
for example, is a ConcurrentMap implementation which easily 
handles any combination of strong, soft or weak keys with 
strong, soft or weak values.

Static utility classes include:

* Comparators. Natural order, compound, null-friendly, 
  ad-hoc . . .
* Iterators and Iterables. Element-based equality, cycle, 
  concat, partition, filter with predicate, transform with 
  function . . .
* Lists, Sets and Maps. A plethora of convenient factory 
  methods and much more.
* PrimitiveArrays: "boxing"/"unboxing" of primitive arrays 

And there's more:

* Forwarding collections
* Constrained collections
* Implementation helpers like AbstractIterator 

%package javadoc
Summary:        Javadoc for %{name}
Group:          Development/Documentation
Requires:       jpackage-utils

%description javadoc
Javadoc for %{name}.

%if %with repolib
%package repolib
Summary:        Artifacts to be uploaded to a repository library
Group:          Development/Libraries/Java

%description repolib
Artifacts to be uploaded to a repository library.
This package is not meant to be installed but so its contents
can be extracted through rpm2cpio.
%endif

%prep
%setup -q -n google-collect-%{namedversion}
mkdir src
pushd src
unzip -q ../src-1.0.zip
popd
cp %{SOURCE2} build.xml
cp %{SOURCE3} build.properties
cp %{SOURCE4} COPYING
mkdir lib
ln -s $(build-classpath jsr-305/ri) lib/jsr305.jar
ln -s $(build-classpath junit4) lib/junit.jar
ln -s $(build-classpath cglib) lib/cglib-nodep-2.2.jar
ln -s $(build-classpath easymock2) lib/easymock-2.4.jar
ln -s $(build-classpath easymock-classextension2) lib/easymockclassextension-2.4.jar
ln -s $(build-classpath tl4j) lib/tl4j-1.1.0.jar

tar xzf %{SOURCE5}
mv %{name}-testfw testfw
tar xzf %{SOURCE6}
mv %{name}-test test

%patch0 -p1 -b .sav0
%patch1 -p0 -b .sav1
%patch2 -p0 -b .sav2
%patch3 -p1 -b .sav3

%build
export OPT_JAR_LIST=:
export CLASSPATH=`%{_bindir}/build-classpath objectweb-asm/asm`
%{ant} -Dbuild.sysclasspath=first -Dversion=%{namedversion} jar javadoc test

%install
%{__rm} -rf %{buildroot}

# jars
%{__mkdir_p} %{buildroot}%{_javadir}
%{__cp} -p build/dist/google-collect-%{namedversion}/google-collect-%{namedversion}.jar %{buildroot}%{_javadir}/%{name}-%{namedversion}.jar
%{__ln_s} %{name}-%{namedversion}.jar %{buildroot}%{_javadir}/google-collect-%{namedversion}.jar
(cd %{buildroot}%{_javadir} && for jar in *-%{namedversion}*; do %{__ln_s} ${jar} ${jar/-%{namedversion}/}; done)

# poms
%add_to_maven_depmap com.google.code.google-collections %{name} %{namedversion} JPP %{name}
%add_to_maven_depmap com.google.collections %{name} %{namedversion} JPP %{name}

%{__mkdir_p} %{buildroot}%{_datadir}/maven2/poms
%{__cp} -p %{SOURCE1} %{buildroot}%{_datadir}/maven2/poms/JPP-%{name}.pom

# javadoc
%{__mkdir_p} %{buildroot}%{_javadocdir}/%{name}-%{namedversion}
%{__cp} -pr javadoc/* %{buildroot}%{_javadocdir}/%{name}-%{namedversion}
%{__ln_s} %{name}-%{namedversion} %{buildroot}%{_javadocdir}/%{name}
%{__ln_s} %{name}-%{namedversion} %{buildroot}%{_javadocdir}/google-collect-%{namedversion}
%{__ln_s} google-collect-%{namedversion} %{buildroot}%{_javadocdir}/google-collect

%if %with repolib
export MAVEN_REPO_LOCAL=`pwd`/.m2/repository
export URL=file://%{buildroot}%{_javadir}/repository.jboss.com
export MAVEN_OPTS="-Xms1g -Xmx1g"
%{_bindir}/mvn-jpp deploy:deploy-file -Dmaven.repo.local=${MAVEN_REPO_LOCAL} -DpomFile=%{buildroot}%{_datadir}/maven2/poms/JPP-%{name}.pom -Dfile=%{buildroot}%{_javadir}/%{name}-%{namedversion}.jar -Durl=${URL} -DrepositoryId=oss-releases
%endif

%clean
%{__rm} -rf %{buildroot}

%post
%update_maven_depmap

%postun
%update_maven_depmap

%files
%defattr(0644,root,root,0755)
%doc COPYING
%{_javadir}*/%{name}-%{namedversion}.jar
%{_javadir}*/%{name}.jar
%{_javadir}*/google-collect-%{namedversion}.jar
%{_javadir}*/google-collect.jar
%{_datadir}/maven2/poms/JPP-%{name}.pom
%{_mavendepmapfragdir}/%{name}

%files javadoc
%defattr(0644,root,root,0755)
%{_javadocdir}/%{name}-%{namedversion}
%{_javadocdir}/%{name}
%{_javadocdir}/google-collect-%{namedversion}
%{_javadocdir}/google-collect

%if %with repolib
%files repolib
%defattr(0644,root,root,0755)
%dir %{_javadir}*
%exclude %dir %{_javadocdir}
%{_javadir}*/repository.jboss.com
%endif

%changelog
* Sun Nov 13 2011 David Walluck <dwalluck@redhat.com> 0:1.0-3.3
- fix build with jsr-305

* Wed Sep 14 2011 David Walluck <dwalluck@redhat.com> 0:1.0-3.2
- fix pom name
- update file list for brew
- add repolib

* Tue Feb 08 2011 David Walluck <dwalluck@redhat.com> 0:1.0-3.1
- remove jpackage-utils version requirement
- change jsr-305 symlink for Fedora
- fix patching

* Tue Dec 21 2010 Ralph Apel <r.apel@r-apel.de> 0:1.0-3
- Fix additional depmap frag

* Tue Dec 21 2010 Ralph Apel <r.apel@r-apel.de> 0:1.0-2
- Add another depmap frag

* Mon Dec 20 2010 Ralph Apel <r.apel@r-apel.de> 0:1.0-1
- 1.0 final for JPP-6

* Mon Sep 14 2009 David Walluck <dwalluck@redhat.com> 0:1.0-0.rc2.1
- 1.0-rc2 (20090604)
- remove GCJ support

* Mon Apr 20 2009 David Walluck <dwalluck@redhat.com> 0:1.0-0.rc1.1
- 1.0-rc1 (20090406)
- add javadoc symlinks for google-collect

* Thu Aug 07 2008 David Walluck <dwalluck@redhat.com> 0:0.7-1
- release
